@@ -1,91 +1,62 @@
 from streamad.base import BaseDetector
-import pandas as pd
 import numpy as np
 import mmh3
 
 
 class xStreamDetector(BaseDetector):
-    """Multivariate xStreamDetector :cite:`DBLP:conf/kdd/ManzoorLA18`. See `xStream <https://cmuxstream.github.io/>`_"""
-
     def __init__(
         self,
+        window_len: int = 100,
         n_components: int = 50,
-        n_chains: int = 100,
+        n_chains: int = 50,
         depth: int = 25,
-        window_size: int = 25,
     ):
-        """xStream detector for multivariate data.
+        """Multivariate xStreamDetector :cite:`DBLP:conf/kdd/ManzoorLA18`.
 
         Args:
+            window_len (int, optional): Size of reference window. Defaults to 100.
             n_components (int, optional): Number of streamhash projection, similar to feature numbers. Defaults to 50.
             n_chains (int, optional): Number of half-space chains. Defaults to 100.
             depth (int, optional): Maximum depth for each chain. Defaults to 25.
-            window_size (int, optional): Size of reference window. Defaults to 25.
         """
+
         super().__init__()
         self.projector = StreamhashProjector(
             num_components=n_components, density=1 / 3.0
         )
-        self.window_size = window_size
-        self.count = 0
+        self.window_len = window_len
         self.cur_window = []
         self.ref_window = []
+
         delta = np.ones(n_components) * 0.5
         self.hs_chains = _hsChains(
             deltamax=delta, n_chains=n_chains, depth=depth
         )
-        self.scores = []
 
     def fit(self, X: np.ndarray):
-        """xStreamDetector collects data with a window length, projects them via streamhash projector, and then scores the observed data.
-
-        Args:
-            X (np.ndarray): Current observation.
-        """
-        self.count += 1
 
         projected_X = self.projector.transform(X)
         self.cur_window.append(projected_X)
         self.hs_chains.fit(projected_X)
 
-        if self.count % self.window_size == 0:
-            self.ref_window = self.cur_window
-            self.cur_window = []
+        self.ref_window = self.cur_window
+        self.cur_window = []
 
-            deltamax = np.ptp(self.ref_window, axis=0) / 2.0
-            deltamax[np.abs(deltamax) <= 0.0001] = 1.0
+        deltamax = np.ptp(self.ref_window, axis=0) / 2.0
+        deltamax[np.abs(deltamax) <= 0.0001] = 1.0
 
-            self.hs_chains.set_deltamax(deltamax=deltamax)
-            self.hs_chains.next_window()
+        self.hs_chains.set_deltamax(deltamax=deltamax)
+        self.hs_chains.next_window()
 
         return self
 
     def score(self, X: np.ndarray) -> float:
-        """Score the current observation. None for init period and float for the probability of anomalousness.
 
-        Args:
-            X (np.ndarray): Current observation.
-
-        Returns:
-            float: Anomaly probability.
-        """
         projected_X = self.projector.transform(X)
 
         score = -1.0 * self.hs_chains.score_chains(projected_X)
-        self.scores.append(score)
 
-        if self.count < self.window_size:
-            return 0.0
-
-        score = self.scores[-1]
-
-        prob = (
-            1.0
-            * len(np.where(np.array(self.scores) < score)[0])
-            / len(self.scores)
-        )
-
-        return abs(prob)
+        return score
 
 
 class _Chain:
@@ -246,7 +217,7 @@ class StreamhashProjector:
 
     def _hash_string(self, k, s):
 
-        hash_value = int(mmh3.hash(s, signed=False, seed=k)) / (2.0**32 - 1)
+        hash_value = int(mmh3.hash(s, signed=False, seed=k)) / (2.0 ** 32 - 1)
         s = self.density
         if hash_value <= s / 2.0:
             return -1 * self.constant
