@@ -10,8 +10,7 @@
 
 from .stream_generator import StreamGenerator
 from .math_toolkit import StreamStatistic
-from .dataset import MultivariateDS, UnivariateDS
-from .eval import AUCMetric
+from .dataset import MultivariateDS, UnivariateDS, CustomDS
 from .plot import plot
 
 
@@ -20,6 +19,6 @@ __all__ = [
     "StreamStatistic",
     "MultivariateDS",
     "UnivariateDS",
-    "AUCMetric",
+    "CustomDS",
     "plot",
 ]
